@@ -19,7 +19,12 @@ import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-codedeploy", "1.49.0", __name__[0:-6], "aws-codedeploy@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-codedeploy",
+    "1.51.0",
+    __name__[0:-6],
+    "aws-codedeploy@1.51.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
